;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "closql" "20251101.1940"
  "Store EIEIO objects using EmacSQL."
  '((emacs   "28.1")
    (compat  "30.1")
    (emacsql "4.3"))
  :url "https://github.com/emacscollective/closql"
  :commit "4a60723ae4bfe809a9affcf3306cb40e0ca1ca6c"
  :revdesc "4a60723ae4bf"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.closql@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.closql@jonas.bernoulli.dev")))
